SPACING = 3
FULLSCREEN = False
RESOLUTION = (1600, 900)
PROTOTYPE_SCALE = 83/100
SCALE = 5 / 16
ACTION_SIZE = (int(70 * PROTOTYPE_SCALE), int(98 * PROTOTYPE_SCALE))
HEX_SIZE = 600 * SCALE * PROTOTYPE_SCALE
WINDOW_CENTER = (RESOLUTION[0] / 2, RESOLUTION[1] / 2)
CARD_SIZE = (int(70 * PROTOTYPE_SCALE), int(98 * PROTOTYPE_SCALE))#(35, 45)